==> clj-poly-0.2.22-20250512.135701-14.jar: polylith/clj/core/doc/navigation/more.clj <==
(ns ^:no-doc polylith.clj.core.doc.navigation.more
  (:require [polylith.clj.core.doc.navigation.calculator :as calculator]))

(def clojurescript-podcast-part1 "https://podcasts.apple.com/se/podcast/s4-e21-polylith-with-joakim-james-and-furkan-part-1/id1461500416?i=1000505948894")

(def config {:high-level {:url "https://polylith.gitbook.io/polylith"
                          :sharing-code {:url "https://polylith.gitbook.io/polylith/introduction/sharing-code"}
                          :testing-incrementally {:url "https://polylith.gitbook.io/polylith/introduction/testing-incrementally"}
                          :polylith-in-a-nutshell {:url "https://polylith.gitbook.io/polylith/introduction/polylith-in-a-nutshell"}
                          :workspace {:url "https://polylith.gitbook.io/polylith/architecture/2.1.-workspace"}
                          :component {:url "https://polylith.gitbook.io/polylith/architecture/2.3.-component"}
                          :base {:url "https://polylith.gitbook.io/polylith/architecture/2.3.-component"}
                          :project {:url "https://polylith.gitbook.io/polylith/architecture/2.6.-project"}
                          :development-project {:url "https://polylith.gitbook.io/polylith/architecture/2.4.-development"}
                          :bring-it-all-together {:url "https://polylith.gitbook.io/polylith/architecture/bring-it-all-together"}
                          :simplicity {:url "https://polylith.gitbook.io/polylith/architecture/simplicity"}
                          :tool {:url "https://polylith.gitbook.io/polylith/tool/the-polylith-plugin"}
                          :current-architectures {:url "https://polylith.gitbook.io/polylith/conclusion/current-arcitectures"}
                          :advantages-of-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/advantages-of-polylith"}
                          :transitioning-to-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/should-you-convert-your-system"}
                          :production-systems {:url "https://polylith.gitbook.io/polylith/conclusion/production-systems"}
                          :why-the-name-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/the-name"}
                          :videos {:url "https://polylith.gitbook.io/polylith/conclusion/videos"}
                          :faq {:url "https://polylith.gitbook.io/polylith/conclusion/faq"}
                          :who-made-this {:url "https://polylith.gitbook.io/polylith/conclusion/who-made-polylith"}}
             :slack {:url "https://clojurians.slack.com/archives/C013B7MQHJQ"}
             :python-tool {:url "https://davidvujic.github.io/python-polylith-docs"}
             :in-japanese {:url "https://zenn.dev/shinseitaro/books/clojure-polylith"}
             :blog-posts {:url "https://polylith.gitbook.io/polylith/#read-a-blog-post"
                          :understanding-polylith-through-the-lens-of-hexagonal-architecture {:url "https://medium.com/@joakimtengstrand/understanding-polylith-through-the-lens-of-hexagonal-architecture-8e7c8757dab1"}
                          :leveraging-polylith-to-improve-consistency-reduce-complexity-and-increase-changeability {:url "https://medium.com/qantas-engineering-blog/leveraging-polylith-to-improve-consistency-reduce-complexity-and-increase-changeability-2031dd3d5f3d"}
                          :a-fresh-take-on-monorepos-in-python {:url "https://davidvujic.blogspot.com/2022/02/a-fresh-take-on-monorepos-in-python.html"}
                          :how-polylith-came-to-life {:url "https://medium.com/@joakimtengstrand/the-polylith-architecture-1eec55c5ebce"}
                          :the-monorepos-polylith-series {:url "https://corfield.org/blog/2021/04/21/deps-edn-monorepo-2"}
                          :the-micro-monolith-architecture {:url "https://medium.com/@joakimtengstrand/the-micro-monolith-architecture-d135d9cafbe"}
                          :the-origin-of-complexity {:url "https://itnext.io/the-origin-of-complexity-8ecb39130fc"}}
             :workspaces {:url "https://polylith.gitbook.io/polylith#look-at-working-code"
                          :demo-rama-electric {:url "https://github.com/jeans11/demo-rama-electric"}
                          :game-of-life {:url "https://github.com/tengstrand/game-of-life"}
                          :integrant-system {:url "https://github.com/polyfy/polylith/tree/master/examples/integrant-system"}
                          :polylith {:url "https://github.com/polyfy/polylith"}
                          :realworld {:url "https://github.com/furkan3ayraktar/clojure-polylith-realworld-example-app/tree/e6f7f200bc46e4e2595e123947eec442ad91c9ab"}
                          :usermanager {:url "https://github.com/seancorfield/usermanager-example/tree/polylith"}}
             :videos {:url "https://polylith.gitbook.io/polylith/conclusion/videos"
                      :polylith-in-a-nutshell {:url "https://youtu.be/Xz8slbpGvnk"}
                      :collaborative-learning-polylith {:url "https://youtu.be/_tpNKAv4fro"}
                      :developer-tooling-for-speed-and-productivity-in-2024 {:url "https://youtu.be/pVvuyaRDA58?si=rBFMEyGtspdmGV29&t=1333"}
                      :the-last-architecture-you-will-ever-need {:url "https://youtu.be/pebwHmibla4"}
                      :a-fresh-take-on-monorepos-in-python {:url "https://www.youtube.com/watch?v=HU61vjZPPfQ"}
                      :polylith–a-software-architecture-based-on-lego-like-blocks {:url "https://www.youtube.com/watch?v=wy4LZykQBkY"}
                      :how-the-polylith-repo-has-evolved-over-time {:url "https://youtu.be/cfVzy9iPpLg"}}
             :podcasts {:url "https://polylith.gitbook.io/polylith/#listen-to-a-podcast"
                        :polylith-with-joakim-james-and-furkan {:url clojurescript-podcast-part1
                                                                :part {:url clojurescript-podcast-part1
                                                                       :exclude-from-navigation? true}
                                                                :part1 {:url clojurescript-podcast-part1}
                                                                :part2 {:url "https://podcasts.apple.com/se/podcast/s4-e22-polylith-with-joakim-james-and-furkan-part-2/id1461500416?i=1000507542984"}}}})

(def navigation (calculator/navigation config))

==> clj-poly-0.3.21-20240721.014029-2.jar: polylith/clj/core/doc/navigation/more.clj <==
(ns ^:no-doc polylith.clj.core.doc.navigation.more
  (:require [polylith.clj.core.doc.navigation.calculator :as calculator]))

(def clojurescript-podcast-part1 "https://podcasts.apple.com/se/podcast/s4-e21-polylith-with-joakim-james-and-furkan-part-1/id1461500416?i=1000505948894")

(def config {:high-level {:url "https://polylith.gitbook.io/polylith"
                          :sharing-code {:url "https://polylith.gitbook.io/polylith/introduction/sharing-code"}
                          :testing-incrementally {:url "https://polylith.gitbook.io/polylith/introduction/testing-incrementally"}
                          :polylith-in-a-nutshell {:url "https://polylith.gitbook.io/polylith/introduction/polylith-in-a-nutshell"}
                          :workspace {:url "https://polylith.gitbook.io/polylith/architecture/2.1.-workspace"}
                          :component {:url "https://polylith.gitbook.io/polylith/architecture/2.3.-component"}
                          :base {:url "https://polylith.gitbook.io/polylith/architecture/2.3.-component"}
                          :project {:url "https://polylith.gitbook.io/polylith/architecture/2.6.-project"}
                          :development-project {:url "https://polylith.gitbook.io/polylith/architecture/2.4.-development"}
                          :bring-it-all-together {:url "https://polylith.gitbook.io/polylith/architecture/bring-it-all-together"}
                          :simplicity {:url "https://polylith.gitbook.io/polylith/architecture/simplicity"}
                          :tool {:url "https://polylith.gitbook.io/polylith/tool/the-polylith-plugin"}
                          :current-architectures {:url "https://polylith.gitbook.io/polylith/conclusion/current-arcitectures"}
                          :advantages-of-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/advantages-of-polylith"}
                          :transitioning-to-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/should-you-convert-your-system"}
                          :production-systems {:url "https://polylith.gitbook.io/polylith/conclusion/production-systems"}
                          :why-the-name-polylith {:url "https://polylith.gitbook.io/polylith/conclusion/the-name"}
                          :videos {:url "https://polylith.gitbook.io/polylith/conclusion/videos"}
                          :faq {:url "https://polylith.gitbook.io/polylith/conclusion/faq"}
                          :who-made-this {:url "https://polylith.gitbook.io/polylith/conclusion/who-made-polylith"}}
             :slack {:url "https://clojurians.slack.com/archives/C013B7MQHJQ"}
             :python-tool {:url "https://davidvujic.github.io/python-polylith-docs"}
             :in-japanese {:url "https://zenn.dev/shinseitaro/books/clojure-polylith"}
             :blog-posts {:url "https://polylith.gitbook.io/polylith/#read-a-blog-post"
                          :understanding-polylith-through-the-lens-of-hexagonal-architecture {:url "https://medium.com/@joakimtengstrand/understanding-polylith-through-the-lens-of-hexagonal-architecture-8e7c8757dab1"}
                          :leveraging-polylith-to-improve-consistency-reduce-complexity-and-increase-changeability {:url "https://medium.com/qantas-engineering-blog/leveraging-polylith-to-improve-consistency-reduce-complexity-and-increase-changeability-2031dd3d5f3d"}
                          :a-fresh-take-on-monorepos-in-python {:url "https://davidvujic.blogspot.com/2022/02/a-fresh-take-on-monorepos-in-python.html"}
                          :how-polylith-came-to-life {:url "https://medium.com/@joakimtengstrand/the-polylith-architecture-1eec55c5ebce"}
                          :the-monorepos-polylith-series {:url "https://corfield.org/blog/2021/04/21/deps-edn-monorepo-2"}
                          :the-micro-monolith-architecture {:url "https://medium.com/@joakimtengstrand/the-micro-monolith-architecture-d135d9cafbe"}
                          :the-origin-of-complexity {:url "https://itnext.io/the-origin-of-complexity-8ecb39130fc"}}
             :workspaces {:url "https://polylith.gitbook.io/polylith/#look-at-working-code"
                          :game-of-life {:url "https://github.com/tengstrand/game-of-life"}
                          :polylith {:url "https://github.com/polyfy/polylith"}
                          :realworld {:url "https://github.com/furkan3ayraktar/clojure-polylith-realworld-example-app/tree/e6f7f200bc46e4e2595e123947eec442ad91c9ab"}
                          :usermanager {:url "https://github.com/seancorfield/usermanager-example/tree/polylith"}}
             :videos {:url "https://polylith.gitbook.io/polylith/conclusion/videos"
                      :polylith-in-a-nutshell {:url "https://youtu.be/Xz8slbpGvnk"}
                      :collaborative-learning-polylith {:url "https://youtu.be/_tpNKAv4fro"}
                      :the-last-architecture-you-will-ever-need {:url "https://youtu.be/pebwHmibla4"}
                      :a-fresh-take-on-monorepos-in-python {:url "https://www.youtube.com/watch?v=HU61vjZPPfQ"}
                      :polylith–a-software-architecture-based-on-lego-like-blocks {:url "https://www.youtube.com/watch?v=wy4LZykQBkY"}
                      :how-the-polylith-repo-has-evolved-over-time {:url "https://youtu.be/cfVzy9iPpLg"}}
             :podcasts {:url "https://polylith.gitbook.io/polylith/#listen-to-a-podcast"
                        :polylith-with-joakim-james-and-furkan {:url clojurescript-podcast-part1
                                                                :part {:url clojurescript-podcast-part1
                                                                       :exclude-from-navigation? true}
                                                                :part1 {:url clojurescript-podcast-part1}
                                                                :part2 {:url "https://podcasts.apple.com/se/podcast/s4-e22-polylith-with-joakim-james-and-furkan-part-2/id1461500416?i=1000507542984"}}}})

(def navigation (calculator/navigation config))
